void DrawMeBaby()
{

  gStyle->SetTextSize(0.1);

  new TCanvas();

  TF1 *muform = new TF1("muform",dEdx,0.1,20,1);
  muform->SetParameter(0,105.658357);  //muon
  muform->SetLineColor(4);
  muform->SetMarkerColor(4);
  muform->SetNpx(1000);
  muform->SetTitle("Energy Loss due to Ionization");

  TF1 *piform = new TF1("piform",dEdx,0.1,20,1);
  piform->SetParameter(0,139.57018); //pion
  piform->SetLineColor(6);
  piform->SetMarkerColor(6);
  piform->SetNpx(1000);

  muform->Draw();
  piform->Draw("same");

  c1->SetLogx();
  //c1->SetLogy();
  c1->SetGridx();
  c1->SetGridy();

  muform->GetHistogram()->GetXaxis()->SetTitle("Particle Momentum (GeV/c)");
  muform->GetHistogram()->GetXaxis()->SetTitleSize(0.06);
  muform->GetHistogram()->GetYaxis()->SetTitle("-dE/dx (MeV g^{-1} cm^{2})");
  muform->GetHistogram()->GetYaxis()->SetTitleSize(0.06);

  TLegend *leg = new TLegend(0.55,0.3,0.8,0.5,"");
  leg->AddEntry(muform,"Muons","p");
  leg->AddEntry(piform,"Pions","p");
  leg->SetFillColor(10);
  leg->Draw();

  c1->Modified();
  c1->Update();
  
  new TCanvas();

  TF1 *percentdiff = new TF1("percentdiff",dEdxPercentDiff,0.1,20,2);
  percentdiff->SetParameters(105.658357,139.57018);
  percentdiff->SetLineColor(3);
  percentdiff->SetTitle("% Difference in Ionization dE/dx for Muons and Pions");
  percentdiff->Draw();

  c1_n2->SetGridx();
  c1_n2->SetGridy();

  percentdiff->GetHistogram()->GetXaxis()->SetTitle("Particle Momentum (GeV/c)");
  percentdiff->GetHistogram()->GetXaxis()->SetTitleSize(0.06);
  percentdiff->GetHistogram()->GetYaxis()->SetTitle("% Difference");
  percentdiff->GetHistogram()->GetYaxis()->SetTitleSize(0.06);
  percentdiff->GetHistogram()->SetAxisRange(1,10);

  c1_n2->Modified();
  c1_n2->Update();

  TPaveText *t1 = (TPaveText*) c1->FindObject("title");
  t1->SetTextSize(0.06);
  t1->SetTextAlign(11);
  TPaveText *t2 = (TPaveText*) c1_n2->FindObject("title");
  t2->SetTextSize(0.06);
  t2->SetTextAlign(11);

  c1->Modified();
  c1->Update();
  c1_n2->Modified();
  c1_n2->Update();

}

double dEdxPercentDiff(double *x,double *par){

  double *mupar = new double;
  mupar[0] = par[0];
  double *pipar = new double;
  pipar[0] = par[1];
  double *y = new double[1];
  y[0] = x[0] + 1.;
  //return 100.*(dEdx(x,mupar)-dEdx(x,pipar))/dEdx(x,mupar);
  return 100.*(dEdx(x,mupar)-dEdx(y,mupar))/dEdx(x,mupar);

}

double dEdx(double *x, double *par){

  double momentum = 1000.*x[0];
  double mass = par[0];

  double K =0.307075;          //MeV/g cm^2 for A=1g/mol
  double z = 1;               //z = charge of incident particle in units of e
  double Z = 26;              //atomic no of iron
  double A = 55.845;         //atomic mass of iron
  double mec2 = 0.510998902; //MeV electron mass x c^2
  double I = 0.0000286;      //excitation energy in MeV
  double delta = 0;        //correction

  //<1GeV
  //x = log10(beta*gamma) 
  //xo = -0.001 
  //x1 = 3.153
  //a=0.147
  //m=2.963
  //c=-4.291
  //xo<x<x1: delta = 4.6052 * x + a * (x1-x)^m + c
  //x>x1: delta = 4.6052*x +c

  //energy of incident particle:
  double energy = sqrt(momentum*momentum + mass*mass);  

  //beta of incident particle:
  double beta = momentum/energy;

  //gamma of incident particle:
  double gamma = energy/mass;


  // max KE that can be imparted to a free e- in single collision:  
  double Tmax = 2*mec2*beta*beta*gamma*gamma/(1. + 2*gamma*mec2/mass + (mec2*mec2/(mass*mass)));

  return (K*z*z*Z/(A*beta*beta))*(0.5*TMath::Log((2*mec2*beta*beta*gamma*gamma*Tmax)/(I*I)) - beta*beta - delta/2);

}






